@@ -49,7 +49,9 @@ def exec_nb(fname, pip_install=True):
 
 
 @patch
-def prettytb(self: CaptureShell, fname:Union[Path, str]=None, simple=False):  # filename to print alongside the traceback
+def prettytb(
+    self: CaptureShell, fname: Union[Path, str] = None, simple=False
+):  # filename to print alongside the traceback
     "Show a pretty traceback for notebooks, optionally printing `fname`."
     fname = fname if fname else self._fname
     _fence = "=" * 75
@@ -69,8 +71,8 @@ def run_one(
     no_run: bool = False,
     pip_install=False,
     github_issue=False,
-    repo="nb_helpers",
-    owner="wandb",
+    repo=None,
+    owner=None,
 ):
     "Run nb `fname` and timeit, recover exception"
     did_run, skip, exec_time = False, False, time.time()
@@ -82,7 +84,7 @@ def run_one(
     skip = skip_nb(notebook, lib_name)
 
     if skip or no_run:
-        return (fname, "skip", 0), None
+        return "skip", 0
     else:
         did_run, shell = exec_nb(fname, pip_install=pip_install)
     if shell.exc:
@@ -90,7 +92,7 @@ def run_one(
         logger.error(f"Error in {fname}:{shell.exc[1]}")
         if github_issue:
             create_issue_nb_fail(fname, shell.prettytb(fname, simple=True), repo=repo, owner=owner)
-    return (fname, "ok" if did_run else "fail", time.time() - exec_time)
+    return "ok" if did_run else "fail", time.time() - exec_time
 
 
 @call_parse
@@ -101,8 +103,8 @@ def run_nbs(
     no_run: Param("Do not run any notebook", store_true) = False,
     pip_install: Param("Run cells with !pip install", store_true) = False,
     github_issue: Param("Create a github issue if notebook fails", store_true) = False,
-    repo: Param("Github repo to create issue in", str) = "nb_helpers",
-    owner: Param("Github owner to create issue in", str) = "wandb",
+    repo: Param("Github repo to create issue in", str) = None,
+    owner: Param("Github owner to create issue in", str) = None,
 ):
     if verbose:
         logger.logger.setLevel(logging.DEBUG)
@@ -112,10 +114,10 @@ def run_nbs(
 
     with Progress(console=logger.console) as progress:
         task_run_nbs = progress.add_task("Running nbs...", total=len(files))
-        for nb_path in files:
-            progress.update(task_run_nbs, description=f"Running nb: {str(nb_path.relative_to(nb_path.parent.parent))}")
-            (fname, run_status, runtime) = run_one(
-                nb_path,
+        for fname in files:
+            progress.update(task_run_nbs, description=f"Running nb: {str(fname.relative_to(fname.parent.parent))}")
+            (run_status, runtime) = run_one(
+                fname,
                 lib_name=lib_name,
                 no_run=no_run,
                 pip_install=pip_install,
@@ -124,7 +126,7 @@ def run_nbs(
                 owner=owner,
             )
             progress.advance(task_run_nbs)
-            logger.writerow_incolor(fname, run_status, runtime, colab_link=get_colab_url(nb_path, branch))
+            logger.writerow_incolor(fname, run_status, runtime, colab_link=get_colab_url(fname, branch))
             time.sleep(0.1)
 
     logger.to_table()
