@@ -57,6 +57,7 @@ def summary_nbs(
     logger.info(f"Reading {len(files)} notebooks")
 
     repo_path = git_local_repo(files[0])
+    branch = git_main_name(repo_path)
 
     for nb_path in files:
         nb = read_nb(nb_path)
@@ -72,7 +73,7 @@ def summary_nbs(
             ", ".join(libs),
             str(colab_cell_idx) if colab_cell_idx != -1 else "",
         ]
-        colab_link = get_colab_url(nb_path, branch=git_main_name(nb_path))
+        colab_link = get_colab_url(nb_path, branch)
         logger.writerow(row, colab_link)
     logger.to_table()
     logger.to_csv(Path(out_file).with_suffix(".csv"))
