@@ -1,6 +1,6 @@
 from pathlib import Path
 
-from nbformat import read
+from execnb.nbio import read_nb
 from tests import TEST_PATH, TEST_NB, FAIL_NB
 from nb_helpers.utils import (
     detect_imported_libs,
@@ -8,10 +8,9 @@ from nb_helpers.utils import (
     is_nb,
     find_nbs,
     git_origin_repo,
-    read_nb,
     search_string_in_nb,
 )
-from nb_helpers.colab import in_colab, has_colab_badge, add_colab_badge
+from nb_helpers.colab import has_colab_badge, add_colab_badge
 
 
 def test_is_nb():
@@ -25,15 +24,10 @@ def test_is_nb():
 
 def test_find_nbs():
     valid_nbs = [f.name for f in find_nbs(TEST_PATH)]
-    assert len(valid_nbs) == 6
+    assert len(valid_nbs) == 7
     assert ("test_nb.ipynb" in valid_nbs) and ("test_nb2.ipynb" in valid_nbs)
 
 
-# colab
-def test_colab():
-    assert not in_colab(), f"We are not in colab"
-
-
 # nb
 def test_search_string_in_nb():
     nb = read_nb(TEST_NB)
